from fastapi import FastAPI
from starlette.middleware.cors import CORSMiddleware

from accounts.api.api_v1.api import router
from accounts.core.config import settings

accounts = FastAPI(
    title=settings.PROJECT_NAME, openapi_url=f"{settings.API_V1_STR}/openapi.json"
)

# Set all CORS enabled origins
if settings.BACKEND_CORS_ORIGINS:
    accounts.add_middleware(
        CORSMiddleware,
        allow_origins=[str(origin) for origin in settings.BACKEND_CORS_ORIGINS],
        allow_credentials=True,
        allow_methods=["*"],
        allow_headers=["*"],
    )

accounts.include_router(router, prefix=settings.API_V1_STR)


@accounts.get("/health")
def health():
    return {"message": "ok!"}