# Import all the models, so that Base has them before being
# imported by Alembic
from accounts.db.base_class import Base  # noqa
from accounts.models.user import User  # noqa
from accounts.models.role import Role
from accounts.models.user_role import UserRole
from accounts.models.account import Account
